%global security_hardening nonow
%define glibc_target_cpu %{_build}

# Don't depend on bash by default
%define __requires_exclude ^/(bin|usr/bin).*$

# Enable frame pointers for package
%define _include_frame_pointers 1

Summary:        Main C library
Name:           glibc
Version:        2.38
Release:        11%{?dist}
License:        BSD AND GPLv2+ AND Inner-Net AND ISC AND LGPLv2+ AND MIT
Vendor:         Microsoft Corporation
Distribution:   Azure Linux
Group:          Applications/System
URL:            https://www.gnu.org/software/libc
Source0:        https://ftp.gnu.org/gnu/glibc/%{name}-%{version}.tar.xz
Source1:        locale-gen.sh
Source2:        locale-gen.conf
Patch0:         https://www.linuxfromscratch.org/patches/downloads/glibc/glibc-2.38-fhs-1.patch
# Only applicable on ARMv7 targets.
Patch1:         CVE-2020-6096.nopatch
# Only applicable on x32 targets.
Patch2:         CVE-2019-6488.nopatch
# Only applicable on PowerPC targets.
Patch3:         CVE-2020-1751.nopatch
# Marked by upstream/Ubuntu/Red Hat as not a security bug, no fix available
# Rationale: Exploit requires crafted pattern in regex compiler meant only for trusted content
Patch4:         CVE-2018-20796.nopatch
Patch5:         https://www.linuxfromscratch.org/patches/downloads/glibc/glibc-2.38-memalign_fix-1.patch
Patch6:         CVE-2023-4911.patch
Patch7:         CVE-2023-6246.patch
Patch8:         CVE-2023-6779.patch
Patch9:         CVE-2023-6780.patch
# Upstream backport for fixing: nscd fails to build with cleanup handler if built with -fexceptions
Patch10:        nscd-Do-not-rebuild-getaddrinfo-bug-30709.patch
Patch11:        glibc-2.34_pthread_cond_wait.patch
Patch12:        CVE-2023-4527.patch
Patch13:        CVE-2023-4806.patch
Patch14:        CVE-2023-5156.patch
Patch15:        CVE-2024-33599.patch
Patch16:        CVE-2024-33600.patch
# Patch of CVE-2024-33601 fixes CVE-2024-33602 also
Patch17:        CVE-2024-33601.patch
Patch18:        CVE-2025-0395.patch

# Patches for testing
Patch100:       0001-Remove-Wno-format-cflag-from-tests.patch

BuildRequires:  bison
BuildRequires:  gawk
BuildRequires:  gettext
BuildRequires:  kernel-headers
BuildRequires:  texinfo
Requires:       filesystem
Provides:       %{name}-common = %{version}-%{release}
Provides:       /sbin/ldconfig
Provides:       nss_db = %{version}-%{release}
Provides:       rtld(GNU_HASH)
ExcludeArch:    armv7 ppc i386 i686

%description
This library provides the basic routines for allocating memory,
searching directories, opening and closing files, reading and
writing files, string handling, pattern matching, arithmetic,
and so on.

%package devel
Summary:        Header files for glibc
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-headers = %{version}-%{release}

%description devel
These are the header files of glibc.

%package static
Summary:        Static glibc library and runtimes
Group:          Applications/System
Requires:       %{name}-devel = %{version}-%{release}
Provides:       %{name}-static%{?_isa} = %{version}-%{release}

%description static
These are the static artefacts for glibc.

%package lang
Summary:        Additional language files for glibc
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}

%description lang
These are the additional language files of glibc.

%package i18n
Summary:        Additional internationalization files for glibc
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-locale-source = %{version}-%{release}

%description i18n
These are the additional internationalization files of glibc.

%package iconv
Summary:        gconv modules for glibc
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}

%description iconv
These are gconv modules for iconv().

%package tools
Summary:        tools for glibc
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}

%description tools
Extra tools for glibc.

%package nscd
Summary:        Name Service Cache Daemon
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}

%description nscd
Name Service Cache Daemon

%package locales-all
Summary:        Locale Data for Localized Programs
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-i18n = %{version}-%{release}
Requires:       %{name}-lang = %{version}-%{release}

%description locales-all
Locale data for the internationalization features of glibc

%prep
%autosetup -p1
sed -i 's/\\$$(pwd)/`pwd`/' timezone/Makefile
install -vdm 755 %{_builddir}/%{name}-build
# do not try to explicitly provide GLIBC_PRIVATE versioned libraries
%define __find_provides %{_builddir}/%{name}-%{version}/find_provides.sh
%define __find_requires %{_builddir}/%{name}-%{version}/find_requires.sh

# create find-provides and find-requires script in order to ignore GLIBC_PRIVATE errors
cat > find_provides.sh << _EOF
#! /bin/sh
if [ -d /tools ]; then
/tools/lib/rpm/find-provides | grep -v GLIBC_PRIVATE
else
%{_libdir}/rpm/find-provides | grep -v GLIBC_PRIVATE
fi
exit 0
_EOF
chmod +x find_provides.sh

cat > find_requires.sh << _EOF
#! /bin/sh
if [ -d /tools ]; then
/tools/lib/rpm/find-requires %{buildroot} %{glibc_target_cpu} | grep -v GLIBC_PRIVATE
else
%{_libdir}/rpm/find-requires %{buildroot} %{glibc_target_cpu} | grep -v GLIBC_PRIVATE
fi
_EOF
chmod +x find_requires.sh
#___EOF

%build
CFLAGS="`echo " %{build_cflags} " | sed 's/-Wp,-D_FORTIFY_SOURCE=2//'`"
CXXFLAGS="`echo " %{build_cxxflags} " | sed 's/-Wp,-D_FORTIFY_SOURCE=2//'`"
export CFLAGS
export CXXFLAGS

cd %{_builddir}/%{name}-build
echo "rootsbindir=/usr/sbin" > configparms
../%{name}-%{version}/configure \
        --prefix=%{_prefix} \
        --disable-profile \
        --disable-werror \
        --enable-kernel=4.14 \
        --enable-bind-now \
        --enable-static-pie \
%ifarch x86_64
        --enable-cet \
%endif
        --disable-silent-rules \
        libc_cv_slibdir=/usr/lib

make %{?_smp_mflags}

%install
#       Do not remove static libs
pushd %{_builddir}/glibc-build
#       Create directories
make install_root=%{buildroot} install
install -vdm 755 %{buildroot}%{_sysconfdir}/ld.so.conf.d
install -vdm 755 %{buildroot}%{_var}/cache/nscd
install -vdm 755 %{buildroot}%{_libdir}/locale
cp -v ../%{name}-%{version}/nscd/nscd.conf %{buildroot}%{_sysconfdir}/nscd.conf
#       Install locale generation script and config file
cp -v %{SOURCE2} %{buildroot}%{_sysconfdir}
cp -v %{SOURCE1} %{buildroot}%{_sbindir}
#       Remove unwanted cruft
rm -rf %{buildroot}%{_infodir}
#       Install configuration files

# Spaces should not be used in nsswitch.conf in the begining of new line
# Only tab should be used as it expects the same in source code.
# Otherwise "altfiles" will not be added. which may cause dbus.service failure
cat > %{buildroot}%{_sysconfdir}/nsswitch.conf <<- "EOF"
#       Begin /etc/nsswitch.conf

	passwd: files
	group: files
	shadow: files

	hosts: files dns
	networks: files

	protocols: files
	services: files
	ethers: files
	rpc: files
#       End /etc/nsswitch.conf
EOF
cat > %{buildroot}%{_sysconfdir}/ld.so.conf <<- "EOF"
#       Begin /etc/ld.so.conf
	%{_prefix}/local/lib
	/opt/lib
	include %{_sysconfdir}/ld.so.conf.d/*.conf
EOF
popd
%find_lang %{name} --all-name

# Generate all locales
pushd %{_builddir}/%{name}-build
# Install locales
make %{?_smp_mflags} install_root=%{buildroot} localedata/install-locale-files

# To reduce footprint of localedata
# hardlink identical locale files together
hardlink -vc %{buildroot}%{_libdir}/locale
popd

# to do not depend on /bin/bash
sed -i 's@#! /bin/bash@#! /bin/sh@' %{buildroot}%{_bindir}/ldd
# Fix a hard coded path to the executable loader in the ldd script
sed '/RTLDLIST=/s@/usr@@g' -i %{buildroot}%{_bindir}/ldd
sed -i 's@#!/bin/bash@#!/bin/sh@' %{buildroot}%{_bindir}/tzselect

# Determine which static libs are needed in `glibc-devel` - the rest will be put
# into `glibc-static`.  We need to keep the static shims for function that's now
# in `libc.so` (since 2.34 - see https://developers.redhat.com/articles/2021/12/17/why-glibc-234-removed-libpthread)
# and the "statically linked bit" of `libc.so` (called `libc_nonshared.a`)
static_libs_in_devel_pattern="lib\(c_nonshared\|pthread\|dl\|rt\|g\|util\|mcheck\).a"
ls -1 %{buildroot}%{_libdir}/*.a | grep -e "$static_libs_in_devel_pattern" | sed "s:^%{buildroot}::g" > devel.filelist
ls -1 %{buildroot}%{_libdir}/*.a | grep -v -e "$static_libs_in_devel_pattern" | sed "s:^%{buildroot}::g" > static.filelist

%check
cd %{_builddir}/glibc-build

# Results have varied based on the environment the tests are being built
# Summary of test results in local VM:
#      3 FAIL : nptl/tst-cancel1, io/tst-lchmod, nptl/tst-mutex10
#   5040 PASS
#    152 UNSUPPORTED
#     12 XFAIL
#      8 XPASS
# Summary of test results in pipeline (this has shown varying results):
#       7 FAIL
#    5110 PASS
#      79 UNSUPPORTED
#      12 XFAIL
#       8 XPASS
make %{?_smp_mflags} check ||:
n=0
# expected failures in local VM
grep "^FAIL: nptl/tst-cancel1" tests.sum >/dev/null && n=$((n+1)) ||:
grep "^FAIL: io/tst-lchmod" tests.sum >/dev/null && n=$((n+1)) ||:
grep "^FAIL: nptl/tst-mutex10" tests.sum >/dev/null && n=$((n+1)) ||:
[ `grep ^FAIL tests.sum | wc -l` -eq $n ]

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%license COPYING COPYING.LIB LICENSES
%{_libdir}/locale/en_US.utf8
%{_libdir}/locale/C.utf8
%dir %{_sysconfdir}/ld.so.conf.d
%config(noreplace) %{_sysconfdir}/nsswitch.conf
%config(noreplace) %{_sysconfdir}/ld.so.conf
%config(noreplace) %{_sysconfdir}/rpc
%config(missingok,noreplace) %{_sysconfdir}/ld.so.cache
%config %{_sysconfdir}/locale-gen.conf
%ifarch aarch64
/usr/lib/ld-linux-aarch64.so.1
%endif
#%%exclude /lib64/libpcprofile.so
%{_libdir}/*.so*
%{_sbindir}/ldconfig
%{_sbindir}/locale-gen.sh

#%%{_sbindir}/zdump
%{_sbindir}/zic
%{_sbindir}/iconvconfig
%{_bindir}/*
%{_libexecdir}/*
%{_datadir}/i18n/charmaps/UTF-8.gz
%{_datadir}/i18n/charmaps/ISO-8859-1.gz
%{_datadir}/i18n/locales/en_US
%{_datarootdir}/locale/locale.alias
%exclude %{_localstatedir}/lib/nss_db/Makefile
%exclude %{_bindir}/mtrace
%exclude %{_bindir}/pcprofiledump
%exclude %{_bindir}/xtrace

%files iconv
%defattr(-,root,root)
%{_libdir}/gconv/*

%files tools
%defattr(-,root,root)
%{_bindir}/mtrace
%{_bindir}/pcprofiledump
%{_bindir}/xtrace
%{_sbindir}/sln
%{_libdir}/audit/*
#/lib64/libpcprofile.so

%files nscd
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/nscd.conf
%{_sbindir}/nscd
%dir %{_localstatedir}/cache/nscd

%files i18n
%defattr(-,root,root)
%{_datadir}/i18n/charmaps/*.gz
%{_datadir}/i18n/locales/*

%files devel -f devel.filelist
%defattr(-,root,root)
# TODO: Excluding for now to remove dependency on PERL
# /usr/bin/mtrace
# C Runtime files for `-pie`, `-no-pie` and profiled executables as well as for shared libs
%{_libdir}/{,g,M,S}crt1.o
# C Runtime files needed for all targets
%{_libdir}/crt{i,n}.o
%{_includedir}/*

%files static -f static.filelist
%defattr(-,root,root)
# C Runtime files for `-static-pie` and profiled `-static-pie`
%{_libdir}/{r,gr}crt1.o

%files -f %{name}.lang lang
%defattr(-,root,root)

%files locales-all
%defattr(-,root,root)
%{_libdir}/locale/*
%exclude %{_libdir}/locale/en_US.utf8
%exclude %{_libdir}/locale/C.utf8

%changelog
* Thu May 22 2025 Kanishk Bansal <kanbansal@microsoft.com> - 2.38-11
- Patch CVE-2023-4527, CVE-2023-4806, CVE-2024-33599, CVE-2024-33600, CVE-2024-33601, CVE-2025-0395, CVE-2025-4802
- Fix CVE-2023-5156

* Mon May 12 2025 Andrew Phelps <anphel@microsoft.com> - 2.38-10
- Add glibc-2.34_pthread_cond_wait.patch

* Wed Feb 19 2025 Chris Co <chrco@microsoft.com> - 2.38-9
- Re-enable nscd build and packaging

* Mon Aug 26 2024 Rachel Menge <rachelmenge@microsoft.com> - 2.38-8
- Enable check section for glibc

* Wed Aug 21 2024 Chris Co <chrco@microsoft.com> - 2.38-7
- Fix syslog failing to print issue

* Mon Jun 17 2024 Nicolas Guibourge <nicolasg@microsoft.com> - 2.38-6
- Address CVE-2023-4911, CVE-2023-5156, CVE-2023-6246, CVE-2023-6779, CVE-2023-6780

* Wed May 22 2024 Suresh Babu Chalamalasetty <schalam@microsoft.com> - 2.38-5
- Generate and provide glibc all locales in a sub-package

* Fri May 10 2024 Chris Co <chrco@microsoft.com> - 2.38-4
- Enable frame pointers compiler flag

* Mon Mar 11 2024 Dan Streetman <ddstreet@microsoft.com> - 2.38-3
- provide C.utf8 locale

* Tue Feb 27 2024 Dan Streetman <ddstreet@ieee.org> - 2.38-2
- Do NOT rename en_US.utf8 to en_US.UTF-8 (glibc will reduce UTF-8 to utf8, but NOT utf8 to UTF-8)

* Thu Nov 02 2023 Andrew Phelps <anphel@microsoft.com> - 2.38-1
- Upgrade to version 2.38

* Wed Oct 04 2023 Minghe Ren <mingheren@microsoft.com> - 2.35-6
- Add patches for CVE-2023-4806 and CVE-2023-5156

* Tue Oct 03 2023 Mandeep Plaha <mandeepplaha@microsoft.com> - 2.35-5
- Patch CVE-2023-4911

* Fri Jun 30 2023 Andrew Phelps <anphel@microsoft.com> - 2.35-4
- Restore glibc-debuginfo package

* Fri Sep 30 2022 Andy Caldwell <andycaldwell@microsoft> - 2.35-3
- Split `glibc-static` into an actual package containing static libraries and runtime

* Mon May 02 2022 Sriram Nambakam <snambakam@microsoft.com> - 2.35-2
- To remove leading spaces in /etc/nsswitch.conf, use tabs instead of spaces

* Tue Apr 12 2022 Andrew Phelps <anphel@microsoft.com> - 2.35-1
- Upgrade to version 2.35
- Cleanup old patch files

* Wed Mar 02 2022 Andy Caldwell <andycaldwell@microsoft.com> - 2.34-3
- Add support for building `-static-pie` binaries against `glibc`
- Add additional BuildRequires

* Thu Nov 04 2021 Pawel Winogrodzki <pawel.winogrodzki@microsoft.com> - 2.34-2
- Adding missing BR on "perl(File::Find)".
- Fixing licensing information.
- Removing redundant 'Provides'.

* Thu Oct 14 2021 Andrew Phelps <anphel@microsoft.com> - 2.34-1
- Upgrade to version 2.34
- License verified

* Fri Sep 24 2021 Pawel Winogrodzki <pawelwi@microsoft.com> - 2.28-19
- Adding 'Provides' for 'nss_db'.

* Thu Jul 29 2021 Jon Slobodzian <joslobo@microsoft.com> 2.28-18
- Dash Rolled for Merge from 1.0 branch

* Fri Apr 02 2021 Thomas Crain <thcrain@microsoft.com> - 2.28-17
- Merge the following releases from 1.0 to dev branch
- lihl@microsoft.com, 2.28-13: Added patch to resolve CVE-2019-7309, Used autosteup
- thcrain@microsoft.com, 2.28-14: Patch CVE-2019-19126
- mamalisz@microsoft.com, 2.28-15: Exclude binaries(such as bash) from requires list.
- nicolasg@microsoft.com, 2.28-16: Patch CVE-2019-25013
- thcrain@microsoft.com, 2.28-17: Patch CVE-2021-3326
- nisamson@microsoft.com, 2.28-18: Patch CVE-2021-27618

* Thu Mar 25 2021 Henry Li <lihl@microsoft.com> - 2.28-16
- Provides glibc-locale-source from glibc-i18n
- Add back exluded files to glibc-i18n

* Fri Feb 05 2021 Joe Schmitt <joschmit@microsoft.com> - 2.28-15
- Replace incorrect %%{_lib} usage with %%{_libdir}

* Thu Dec 10 2020 Joe Schmitt <joschmit@microsoft.com> - 2.28-14
- Provide isa version of glibc-static.

* Mon Sep 28 2020 Ruying Chen <v-ruyche@microsoft.com> - 2.28-13
- Move some tools from glibc-tools and glibc-iconv to glibc and provide glibc-common
- Provide glibc-static and glibc-headers under glibc-devel

* Wed Jul 29 2020 Thomas Crain <thcrain@microsoft.com> - 2.28-12
- Ignore CVE-2018-20796, as it is not a security issue

* Wed Jul 29 2020 Emre Girgin <mrgirgin@microsoft.com> - 2.28-11
- Disable the debuginfo package for glibc, and use unstripped binaries instead.

* Fri Jun 26 2020 Ruying Chen <v-ruyche@microsoft.com> - 2.28-10
- Added provides for binary capability.

* Thu Jun 11 2020 Henry Beberman <henry.beberman@microsoft.com> - 2.28-9
- Disable -Wp,-D_FORTIFY_SOURCE=2 to build with hardened cflags.

* Tue May 19 2020 Emre Girgin <mrgirgin@microsoft.com> - 2.28-8
- Ignore CVE-2019-6488, CVE-2020-1751, CVE-2020-6096 as they don't apply to aarch64 or x86_64.

* Sat May 09 2020 Nick Samson <nisamson@microsoft.com> - 2.28-7
- Added %%license line automatically

* Fri Mar 20 2020 Andrew Phelps <anphel@microsoft.com> - 2.28-6
- Configure with --disable-werror.

* Mon Dec 02 2019 Saravanan Somasundaram <sarsoma@microsoft.com> - 2.28-5
- Initial CBL-Mariner import from Photon (license: Apache2).

* Fri Jul 12 2019 Ankit Jain <ankitja@vmware.com> - 2.28-4
- Replaced spaces with tab in nsswitch.conf file

* Fri Mar 08 2019 Alexey Makhalov <amakhalov@vmware.com> - 2.28-3
- Fix CVE-2019-9169

* Tue Jan 22 2019 Anish Swaminathan <anishs@vmware.com> - 2.28-2
- Fix CVE-2018-19591

* Tue Aug 28 2018 Alexey Makhalov <amakhalov@vmware.com> - 2.28-1
- Version update. Disable obsolete rpc (use libtirpc) and nsl.

* Tue Jan 23 2018 Xiaolin Li <xiaolinl@vmware.com> - 2.26-10
- Fix CVE-2018-1000001 and CVE-2018-6485

* Mon Jan 08 2018 Xiaolin Li <xiaolinl@vmware.com> - 2.26-9
- Fix CVE-2017-16997

* Thu Dec 21 2017 Xiaolin Li <xiaolinl@vmware.com> - 2.26-8
- Fix CVE-2017-17426

* Tue Nov 14 2017 Alexey Makhalov <amakhalov@vmware.com> - 2.26-7
- Aarch64 support

* Wed Oct 25 2017 Xiaolin Li <xiaolinl@vmware.com> - 2.26-6
- Fix CVE-2017-15670 and CVE-2017-15804

* Tue Oct 10 2017 Alexey Makhalov <amakhalov@vmware.com> - 2.26-5
- Compile out tcache.

* Fri Sep 15 2017 Bo Gan <ganb@vmware.com> - 2.26-4
- exclude tst-eintr1 per official wiki recommendation.

* Tue Sep 12 2017 Alexey Makhalov <amakhalov@vmware.com> - 2.26-3
- Fix makecheck for run in docker.

* Tue Aug 29 2017 Alexey Makhalov <amakhalov@vmware.com> - 2.26-2
- Fix tunables setter.
- Add malloc arena fix.
- Fix makecheck.

* Tue Aug 15 2017 Alexey Makhalov <amakhalov@vmware.com> - 2.26-1
- Version update

* Tue Aug 08 2017 Anish Swaminathan <anishs@vmware.com> - 2.25-4
- Apply fix for CVE-2017-1000366

* Thu May 4  2017 Bo Gan <ganb@vmware.com> - 2.25-3
- Remove bash dependency in post/postun script

* Fri Apr 21 2017 Alexey Makhalov <amakhalov@vmware.com> - 2.25-2
- Added -iconv -tools and -nscd subpackages

* Wed Mar 22 2017 Alexey Makhalov <amakhalov@vmware.com> - 2.25-1
- Version update

* Wed Dec 14 2016 Alexey Makhalov <amakhalov@vmware.com> - 2.24-1
- Version update

* Wed Nov 23 2016 Alexey Makhalov <amakhalov@vmware.com> - 2.22-13
- Install en_US.UTF-8 locale by default

* Wed Nov 16 2016 Alexey Makhalov <amakhalov@vmware.com> - 2.22-12
- Added i18n subpackage

* Tue Oct 25 2016 Alexey Makhalov <amakhalov@vmware.com> - 2.22-11
- Workaround for build failure with "out of memory" message

* Wed Sep 28 2016 Alexey Makhalov <amakhalov@vmware.com> - 2.22-10
- Added pthread_create-fix-use-after-free.patch

* Tue Jun 14 2016 Divya Thaluru <dthaluru@vmware.com> - 2.22-9
- Enabling rpm debug package and stripping the libraries

* Tue May 24 2016 Priyesh Padmavilasom <ppadmavilasom@vmware.com> - 2.22-8
- GA - Bump release of all rpms

* Mon May 23 2016 Divya Thaluru <dthaluru@vmware.com> - 2.22-7
- Added patch for CVE-2014-9761

* Mon Mar 21 2016 Alexey Makhalov <amakhalov@vmware.com> - 2.22-6
- Security hardening: nonow

* Fri Mar 18 2016 Anish Swaminathan <anishs@vmware.com> - 2.22-5
- Change conf file qualifiers

* Fri Mar 11 2016 Priyesh Padmavilasom <ppadmavilasom@vmware.com> - 2.22-4
- Added patch for res_qeury assertion with bad dns config
- Details: https://sourceware.org/bugzilla/show_bug.cgi?id=19791

* Tue Feb 16 2016 Anish Swaminathan <anishs@vmware.com> - 2.22-3
- Added patch for CVE-2015-7547

* Mon Feb 08 2016 Anish Swaminathan <anishs@vmware.com> - 2.22-2
- Added patch for bindresvport blacklist

* Tue Jan 12 2016 Xiaolin Li <xiaolinl@vmware.com> - 2.22-1
- Updated to version 2.22

* Tue Dec 1 2015 Divya Thaluru <dthaluru@vmware.com> - 2.19-8
- Disabling rpm debug package and stripping the libraries

* Wed Nov 18 2015 Divya Thaluru <dthaluru@vmware.com> - 2.19-7
- Adding patch to close nss files database

* Tue Nov 10 2015 Xiaolin Li <xiaolinl@vmware.com> - 2.19-6
- Handled locale files with macro find_lang

* Wed Aug 05 2015 Kumar Kaushik <kaushikk@vmware.com> - 2.19-5
- Adding postun section for ldconfig.

* Tue Jul 28 2015 Alexey Makhalov <amakhalov@vmware.com> - 2.19-4
- Support glibc building against current rpm version.

* Thu Jul 23 2015 Divya Thaluru <dthaluru@vmware.com> - 2.19-3
- Packing locale-gen scripts

* Mon May 18 2015 Touseef Liaqat <tliaqat@vmware.com> - 2.19-2
- Update according to UsrMove.

* Wed Nov 5 2014 Divya Thaluru <dthaluru@vmware.com> - 2.19-1
- Initial build. First version
